@@ -5,7 +5,7 @@ use warnings;
 use Mouse;
 with qw(MouseX::Getopt::GLD);
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub get_options {
     my ($class, @args) = @_;
@@ -27,18 +27,42 @@ Getopt::Constraint::Mouse - A command line options processor uses Mouse's type c
 
 =head1 SYNOPSIS
 
-    # in your script
+in your script
+
+    #!perl
     use Getopt::Constraint::Mouse;
 
     my $options = Getopt::Constraint::Mouse->get_options(
-        foo => +{ isa => 'Str', required => 1     },
-        bar => +{ isa => 'Str', default  => 'Bar' },
+        foo => +{
+            isa           => 'Str',
+            required      => 1,
+            documentation => 'Blah Blah Blah ...',
+        },
+        bar => +{
+            isa           => 'Str',
+            default       => 'Bar',
+            documentation => 'Blah Blah Blah ...',
+        },
     );
 
-    my $foo = $options->{foo};
-    my $bar = $options->{bar};
+    print $options->{foo}, "\n";
+    print $options->{bar}, "\n";
 
-=head1 QUESTINS
+use it
+
+    $ perl ./script.pl --for=Foo --bar=Bar
+    Foo
+    Bar
+
+    $ perl ./script.pl
+    Mandatory parameter 'foo' missing in call to (eval)
+
+    usage: script.pl [-?] [long options...]
+    	-? --usage --help  Prints this usage information.
+    	--foo              Blah Blah Blah ...
+    	--bar              Blah Blah Blah ..
+
+=head1 QUESTIONS
 
 =head2 What are supported Types?
 
